@@ -1,4 +1,5 @@
-use Lingua::EN::Conjugate qw( contraction conjugations conjugate);
+use lib '../lib';
+use Lingua::EN::Conjugate qw( conjugations conjugate);
 
 my @opts =  qw(verb negation question no_pronoun tense passive pronoun modal allow_contractions);
 $opt{verb} = 'do';
@@ -32,6 +33,8 @@ while (1) {
 
             $y = [@y];
         }
+#	else { $y = [$y]; }
+
         $opt{$x} = $y;
     }
 
